@@ -1,6 +1,6 @@
 import logging
 
-from django.contrib.postgres.fields import JSONField
+from django.db.models import JSONField
 
 from isc_common.fields.related import ForeignKeyCascade
 from isc_common.models.audit import AuditModel
