@@ -32,7 +32,7 @@ class Widgets_treesManager(AuditManager):
 
         id_widget = data.get('id_widget')
 
-        if id is None and mode is None and mode is None:
+        if id == None and mode == None and mode == None:
             res, create = super().update_or_create(**data)
             return res
 
