@@ -11,7 +11,7 @@ logger = logging.getLogger(__name__)
 
 class AuditQuerySet(CommonQuerySet):
     def _check_ed_izm_qty(self, **kwargs):
-        if kwargs.get('ed_izm') is not None and kwargs.get('qty') is None or kwargs.get('ed_izm') is None and kwargs.get('qty') is not None:
+        if kwargs.get('ed_izm') != None and kwargs.get('qty') == None or kwargs.get('ed_izm') == None and kwargs.get('qty') != None:
             raise Exception(f'Единица измерения не может быть указана без количества')
 
     def __init__(self, model=None, query=None, using=None, hints=None, alive_only=True):
@@ -19,15 +19,15 @@ class AuditQuerySet(CommonQuerySet):
         super().__init__(model=model, query=query, using=using, hints=hints, alive_only=alive_only)
 
     def rearrange_parent(self, json):
-        _criteria = json.get('data').get('criteria')
-        if isinstance(_criteria, list):
-            for criterion in _criteria:
-                if criterion.get('fieldName') == 'parent_id':
-                    item_id = criterion.get('value')
-                    if (item_id, int):
-                        criteria_lst = [criterion for criterion in _criteria if criterion.get('fieldName') == 'parent_id' and criterion.get('value') is not None]
-                        if len(criteria_lst) > 0:
-                            setAttr(json.get('data'), 'criteria', criteria_lst)
+        # _criteria = json.get('data').get('criteria')
+        # if isinstance(_criteria, list):
+        #     for criterion in _criteria:
+        #         if criterion.get('fieldName') == 'parent_id':
+        #             item_id = criterion.get('value')
+        #             if (item_id, int):
+        #                 criteria_lst = [criterion for criterion in _criteria if criterion.get('fieldName') == 'parent_id' and criterion.get('value') != None]
+        #                 if len(criteria_lst) > 0:
+        #                     setAttr(json.get('data'), 'criteria', criteria_lst)
         return json
 
     def soft_delete(self):
@@ -52,7 +52,7 @@ class AuditQuerySet(CommonQuerySet):
         return self.exclude(deleted_at=None)
 
     def update(self, **kwargs):
-        if kwargs.get('lastmodified') is None:
+        if kwargs.get('lastmodified') == None:
             setAttr(kwargs, 'lastmodified', timezone.now())
         return super().update(**kwargs)
 
@@ -109,11 +109,11 @@ class AuditModel(Model):
 
     @property
     def idHidden(self):
-        return not self is None
+        return not self == None
 
     @property
     def is_deleted(self):
-        return self.deleted_at is not None
+        return self.deleted_at != None
 
     class Meta:
         abstract = True
