@@ -16,7 +16,7 @@ class ParamsQuerySet(AuditQuerySet):
     def get_params(self, request, *args):
         request = DSRequest(request=request)
         data = request.get_data()
-        if data is None or data.get('user_id') is None:
+        if data == None or data.get('user_id') == None:
             return []
 
         # app_id = data.get('app_id')
@@ -41,7 +41,7 @@ class ParamsQuerySet(AuditQuerySet):
     def get_params_key(self, request, *args):
         request = DSRequest(request=request)
         data = request.get_data()
-        if data is None:
+        if data == None:
             return '???'
 
         key = data.get('key')
@@ -94,12 +94,12 @@ class ParamsManager(AuditManager):
         user_id = data.get('user_id')
 
         res = data
-        if key is not None and user_id is not None:
+        if key != None and user_id != None:
             if key[0:1] == "'":
                 key = key[1:len(key) - 1]
             setAttr(data, 'key', key)
 
-            if value is None or value == '':
+            if value == None or value == '':
                 res = super().filter(
                     user_id=user_id,
                     key=key
