@@ -33,14 +33,14 @@ class TreeAuditModelQuerySet(AuditQuerySet):
                         ) -> RawQuerySet:
         db_name = self.model._meta.db_table
 
-        if limit is not None:
+        if limit != None:
             if not isinstance(limit, int):
                 raise Exception(f'limit must be int.')
             limit = f'limit {limit}'
         else:
             limit = ''
 
-        if id is not None:
+        if id != None:
             if isinstance(id, int):
                 id = tuple([id])
             elif isinstance(id, str):
@@ -48,9 +48,9 @@ class TreeAuditModelQuerySet(AuditQuerySet):
             elif not isinstance(id, tuple):
                 raise Exception(f'id must be list or int')
 
-        if sql_text is not None:
+        if sql_text != None:
             res = super().raw(sql_text)
-        elif id is not None:
+        elif id != None:
             sql_text = f'''WITH RECURSIVE r AS (
                                 select s.* from (SELECT {fields}, 1 AS level
                                 FROM {db_name}
@@ -73,7 +73,7 @@ class TreeAuditModelQuerySet(AuditQuerySet):
             sql_text = f'''WITH RECURSIVE r AS (
                                             SELECT *, 1 AS level
                                             FROM {db_name}
-                                            WHERE {child_id if include_self else parent_id} {"IS NULL" if child_parent_value is None else child_parent_value_str}
+                                            WHERE {child_id if include_self else parent_id} {"IS NULL" if child_parent_value == None else child_parent_value_str}
                                                   {"and " + where_clause.replace("where", "") if where_clause else ""}  
 
                                             union all
