@@ -1,4 +1,5 @@
 from decimal import Decimal
+from functools import reduce
 from itertools import chain
 
 from bitfield import BitHandler, Bit
@@ -170,6 +171,8 @@ def compare_2_dict(dict1, dict2):
             messages.append(f'{x_values} != {y_values}')
     return messages
 
+def flen(iterable):
+    return reduce(lambda sum, element: sum + 1, iterable, 0)
 
 class Set:
     _lst = []
