@@ -89,7 +89,10 @@ class WebSocket:
         message = kwrags.get('message')
 
         if not isinstance(message, dict):
-            raise Exception(f'message is not dict instance')
+            if isinstance(message, str):
+                message=dict(message=message)
+            else:
+                raise Exception(f'message is not dict instance')
 
         try:
             key = 'WebSocket.send_message'
@@ -156,6 +159,11 @@ class WebSocket:
         setAttr(kwrags, 'type', 'warn')
         WebSocket.send_typing_message(**kwrags)
 
+    @staticmethod
+    def send_info_message(**kwrags):
+        setAttr(kwrags, 'type', 'info')
+        WebSocket.send_typing_message(**kwrags)
+
     @staticmethod
     def send_typing_message(**kwrags):
 
